summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/connection.hpp (renamed from include/request.hpp)16
-rw-r--r--include/mastodonpp.hpp2
2 files changed, 9 insertions, 9 deletions
diff --git a/include/mastodonpp.hpp b/include/mastodonpp.hpp
index 8b7ed45..2c24c85 100644
--- a/include/mastodonpp.hpp
+++ b/include/mastodonpp.hpp
@@ -20,7 +20,7 @@
#include "api.hpp"
#include "exceptions.hpp"
#include "instance.hpp"
-#include "request.hpp"
+#include "connection.hpp"
#include "return_types.hpp"
/*!
diff --git a/include/request.hpp b/include/connection.hpp
index 36d4f41..1db8286 100644
--- a/include/request.hpp
+++ b/include/connection.hpp
@@ -14,8 +14,8 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef MASTODONPP_REQUEST_HPP
-#define MASTODONPP_REQUEST_HPP
+#ifndef MASTODONPP_CONNECTION_HPP
+#define MASTODONPP_CONNECTION_HPP
#include "api.hpp"
#include "curl_wrapper.hpp"
@@ -30,23 +30,23 @@ namespace mastodonpp
using std::string;
/*!
- * @brief Used to make a request to the Mastodon %API.
+ * @brief Represents a connection to an instance. Used for requests.
*
* @since 0.1.0
*
- * @headerfile request.hpp mastodonpp/request.hpp
+ * @headerfile connection.hpp mastodonpp/connection.hpp
*/
-class Request : public CURLWrapper
+class Connection : public CURLWrapper
{
public:
/*!
* @brief Construct a new Request object.
*
* @param instance An Instance with the access data.
*
* @since 0.1.0
*/
- explicit Request(Instance &instance);
+ explicit Connection(Instance &instance);
/*!
* @brief Make a HTTP GET call.
@@ -75,4 +75,4 @@ private:
} // namespace mastodonpp
-#endif // MASTODONPP_REQUEST_HPP
+#endif // MASTODONPP_CONNECTION_HPP
@@ -30,23 +30,23 @@ namespace mastodonpp
public:
/*!
- * @brief Construct a new Request object.
+ * @brief Construct a new Connection object.
*
* @param instance An Instance with the access data.